@@ -1,7 +1,7 @@
 package App::IODUtils;
 
-our $VERSION = '0.07'; # VERSION
-our $DATE = '2015-03-19'; # DATE
+our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-03-21'; # DATE
 
 use 5.010001;
 
@@ -98,16 +98,62 @@ App::IODUtils - IOD utilities
 
 =head1 VERSION
 
-This document describes version 0.07 of App::IODUtils (from Perl distribution App-IODUtils), released on 2015-03-19.
+This document describes version 0.08 of App::IODUtils (from Perl distribution App-IODUtils), released on 2015-03-21.
 
 =head1 SYNOPSIS
 
 This distribution provides the following command-line utilities:
 
- dump-iod
- get-iod-key
- get-iod-section
- list-iod-sections
+=over
+
+=item * L<delete-iod-key>
+
+=item * L<delete-iod-section>
+
+=item * L<dump-iod>
+
+=item * L<get-iod-key>
+
+=item * L<get-iod-section>
+
+=item * L<insert-iod-key>
+
+=item * L<insert-iod-section>
+
+=item * L<list-iod-sections>
+
+=item * L<parse-iod>
+
+=back
+
+The main feature of these utilities is tab completion.
+
+=head1 SEE ALSO
+
+Below is the list of distributions that provide CLI utilities for various
+purposes, with the focus on providing shell tab completion feature.
+
+L<App::DistUtils>, utilities related to Perl distributions.
+
+L<App::DzilUtils>, utilities related to L<Dist::Zilla>.
+
+L<App::GitUtils>, utilities related to git.
+
+L<App::IODUtils>, utilities related to L<IOD> configuration files.
+
+L<App::LedgerUtils>, utilities related to Ledger CLI files.
+
+L<App::OrgUtils>, utilities related to Org files.
+
+L<App::PlUtils>, utilities related to Perl scripts.
+
+L<App::PMUtils>, utilities related to Perl modules.
+
+L<App::ProgUtils>, utilities related to programs.
+
+L<App::UpfUtils>, utilities related to Unix password/shadow files.
+
+L<App::WeaverUtils>, utilities related to L<Pod::Weaver>.
 
 =head1 HOMEPAGE
 
